==> huaweicloudsdkdataartsstudio-3.1.134-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_data_service_market_apis_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDataServiceMarketApisResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'apis': 'list[AdvancedMallApiDTO]'
    }

    attribute_map = {
        'total': 'total',
        'apis': 'apis'
    }

    def __init__(self, total=None, apis=None):
        """ListDataServiceMarketApisResponse

        The model defined in huaweicloud sdk

        :param total: API总条数。
        :type total: int
        :param apis: API列表。
        :type apis: list[:class:`huaweicloudsdkdataartsstudio.v1.AdvancedMallApiDTO`]
        """
        
        super(ListDataServiceMarketApisResponse, self).__init__()

        self._total = None
        self._apis = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if apis is not None:
            self.apis = apis

    @property
    def total(self):
        """Gets the total of this ListDataServiceMarketApisResponse.

        API总条数。

        :return: The total of this ListDataServiceMarketApisResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this ListDataServiceMarketApisResponse.

        API总条数。

        :param total: The total of this ListDataServiceMarketApisResponse.
        :type total: int
        """
        self._total = total

    @property
    def apis(self):
        """Gets the apis of this ListDataServiceMarketApisResponse.

        API列表。

        :return: The apis of this ListDataServiceMarketApisResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.AdvancedMallApiDTO`]
        """
        return self._apis

    @apis.setter
    def apis(self, apis):
        """Sets the apis of this ListDataServiceMarketApisResponse.

        API列表。

        :param apis: The apis of this ListDataServiceMarketApisResponse.
        :type apis: list[:class:`huaweicloudsdkdataartsstudio.v1.AdvancedMallApiDTO`]
        """
        self._apis = apis

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDataServiceMarketApisResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/list_data_service_market_apis_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListDataServiceMarketApisResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total': 'int',
        'apis': 'list[AdvancedMallApiDTO]'
    }

    attribute_map = {
        'total': 'total',
        'apis': 'apis'
    }

    def __init__(self, total=None, apis=None):
        r"""ListDataServiceMarketApisResponse

        The model defined in huaweicloud sdk

        :param total: API总条数。
        :type total: int
        :param apis: API列表。
        :type apis: list[:class:`huaweicloudsdkdataartsstudio.v1.AdvancedMallApiDTO`]
        """
        
        super(ListDataServiceMarketApisResponse, self).__init__()

        self._total = None
        self._apis = None
        self.discriminator = None

        if total is not None:
            self.total = total
        if apis is not None:
            self.apis = apis

    @property
    def total(self):
        r"""Gets the total of this ListDataServiceMarketApisResponse.

        API总条数。

        :return: The total of this ListDataServiceMarketApisResponse.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        r"""Sets the total of this ListDataServiceMarketApisResponse.

        API总条数。

        :param total: The total of this ListDataServiceMarketApisResponse.
        :type total: int
        """
        self._total = total

    @property
    def apis(self):
        r"""Gets the apis of this ListDataServiceMarketApisResponse.

        API列表。

        :return: The apis of this ListDataServiceMarketApisResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsstudio.v1.AdvancedMallApiDTO`]
        """
        return self._apis

    @apis.setter
    def apis(self, apis):
        r"""Sets the apis of this ListDataServiceMarketApisResponse.

        API列表。

        :param apis: The apis of this ListDataServiceMarketApisResponse.
        :type apis: list[:class:`huaweicloudsdkdataartsstudio.v1.AdvancedMallApiDTO`]
        """
        self._apis = apis

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListDataServiceMarketApisResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
